/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA {
	NI id;
	NimStringV2 s;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* next;
	NI h;
};
struct tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA {
	NI a;
	NI b;
};
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
typedef NimStringV2 tyArray__dyW7vpmfeTYw8kX3EXuaJA[3];
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
typedef NU8 tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
typedef NU8 tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
typedef NU16 tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw;
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef NimStringV2 tyArray__LyWxek8hUPopQalCOVNoKA[42];
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(NimStringV2, differs__linter_u176)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 newName_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, sourceLine__msgs_u1210)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA i_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(NI, identLen__linter_u14)(NimStringV2 line_p0, NI start_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, differ__linter_u110)(NimStringV2 line_p0, NI a_p1, NI b_p2, NimStringV2 x_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, substrEq__linter_u116)(NimStringV2 s_p0, NI pos_p1, NI last_p2, NimStringV2 substr_p3);
static N_INLINE(NimStringV2, X5BX5D___pureZstrutils_u1286)(NimStringV2 s_p0, tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA x_p1);
N_NIMCALL(NimStringV2, mnewString)(NI len_p0);
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimPrepareStrMutationImpl__system_u2430)(NimStringV2* s_p0);
static N_INLINE(tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA, dotdot___stdZstrbasics_u49)(NI a_p0, NI b_p1);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringV2 a_p0, NimStringV2 b_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatOpenArray)(NimStringV2 formatstr_p0, NimStringV2* a_p1, NI a_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, addDeclaredLoc__astmsgs_u16)(NimStringV2* result_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___wordrecg_u307)(tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw e_p0);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, beautifyName__linter_u35)(NimStringV2 s_p0, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, allCharsInSet__pureZstrutils_u1502)(NimStringV2 s_p0, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw theSet_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_NIMCALL(NimStringV2, rawNewString)(NI cap_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqtilde___linter_u27)(NimStringV2 s_p0, NimStringV2* a_p1, NI a_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuStartsWith)(NimStringV2 s_p0, NimStringV2 prefix_p1);
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, nsuToUpperAsciiChar)(NIM_CHAR c_p0);
static N_INLINE(NIM_BOOL, contains__stdZprivateZospaths2_u383)(NIM_CHAR* a_p0, NI a_p0Len_0, NIM_CHAR item_p1);
static N_INLINE(NI, find__stdZprivateZospaths2_u388)(NIM_CHAR* a_p0, NI a_p0Len_0, NIM_CHAR item_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, nsuToLowerAsciiChar)(NIM_CHAR c_p0);
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_2 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__NvI37FoCN5uTD3k9bAqbGMA_3 = {0, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_2};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_4 = { 22 | NIM_STRLIT_FLAG, "\'$1\' should be: \'$2\'$3" };
static const NimStringV2 TM__NvI37FoCN5uTD3k9bAqbGMA_5 = {22, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_4};
static const NimStringV2 TM__NvI37FoCN5uTD3k9bAqbGMA_6 = {0, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_2};
static const struct {
  NI cap; NIM_CHAR data[61+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_8 = { 61 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/linter.nim" };
static const NimStringV2 TM__NvI37FoCN5uTD3k9bAqbGMA_9 = {22, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_4};
static const NimStringV2 TM__NvI37FoCN5uTD3k9bAqbGMA_10 = {0, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_2};
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__NvI37FoCN5uTD3k9bAqbGMA_12 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x03,
0xfe, 0xff, 0xff, 0x87, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_14 = { 3 | NIM_STRLIT_FLAG, "int" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_15 = { 4 | NIM_STRLIT_FLAG, "uint" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_16 = { 4 | NIM_STRLIT_FLAG, "cint" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_17 = { 5 | NIM_STRLIT_FLAG, "cuint" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_18 = { 5 | NIM_STRLIT_FLAG, "clong" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_19 = { 7 | NIM_STRLIT_FLAG, "cstring" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_20 = { 6 | NIM_STRLIT_FLAG, "string" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_21 = { 4 | NIM_STRLIT_FLAG, "char" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_22 = { 4 | NIM_STRLIT_FLAG, "byte" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_23 = { 4 | NIM_STRLIT_FLAG, "bool" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_24 = { 9 | NIM_STRLIT_FLAG, "openArray" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_25 = { 3 | NIM_STRLIT_FLAG, "seq" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_26 = { 5 | NIM_STRLIT_FLAG, "array" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_27 = { 4 | NIM_STRLIT_FLAG, "void" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_28 = { 7 | NIM_STRLIT_FLAG, "pointer" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_29 = { 5 | NIM_STRLIT_FLAG, "float" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_30 = { 5 | NIM_STRLIT_FLAG, "csize" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_31 = { 7 | NIM_STRLIT_FLAG, "csize_t" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_32 = { 7 | NIM_STRLIT_FLAG, "cdouble" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_33 = { 5 | NIM_STRLIT_FLAG, "cchar" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_34 = { 6 | NIM_STRLIT_FLAG, "cschar" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_35 = { 6 | NIM_STRLIT_FLAG, "cshort" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_36 = { 2 | NIM_STRLIT_FLAG, "cu" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_37 = { 3 | NIM_STRLIT_FLAG, "nil" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_38 = { 8 | NIM_STRLIT_FLAG, "typedesc" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_39 = { 4 | NIM_STRLIT_FLAG, "auto" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_40 = { 3 | NIM_STRLIT_FLAG, "any" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_41 = { 5 | NIM_STRLIT_FLAG, "range" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_42 = { 9 | NIM_STRLIT_FLAG, "openarray" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_43 = { 7 | NIM_STRLIT_FLAG, "varargs" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_44 = { 3 | NIM_STRLIT_FLAG, "set" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_45 = { 6 | NIM_STRLIT_FLAG, "cfloat" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_46 = { 3 | NIM_STRLIT_FLAG, "ref" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_47 = { 3 | NIM_STRLIT_FLAG, "ptr" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_48 = { 7 | NIM_STRLIT_FLAG, "untyped" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_49 = { 5 | NIM_STRLIT_FLAG, "typed" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_50 = { 6 | NIM_STRLIT_FLAG, "static" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_51 = { 4 | NIM_STRLIT_FLAG, "sink" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_52 = { 4 | NIM_STRLIT_FLAG, "lent" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_53 = { 4 | NIM_STRLIT_FLAG, "type" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_54 = { 5 | NIM_STRLIT_FLAG, "owned" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__NvI37FoCN5uTD3k9bAqbGMA_55 = { 8 | NIM_STRLIT_FLAG, "iterable" };
static const NimStringV2 TM__NvI37FoCN5uTD3k9bAqbGMA_56 = {22, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_4};
static const NimStringV2 TM__NvI37FoCN5uTD3k9bAqbGMA_57 = {0, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_2};
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NvI37FoCN5uTD3k9bAqbGMA_7 = {{61, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_8},
((NI)135),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NvI37FoCN5uTD3k9bAqbGMA_11 = {{61, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_8},
((NI)150),
((NI)14)}
;
static NIM_CONST tyArray__LyWxek8hUPopQalCOVNoKA TM__NvI37FoCN5uTD3k9bAqbGMA_13 = {{3, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_14},
{4, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_15},
{4, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_16},
{5, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_17},
{5, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_18},
{7, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_19},
{6, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_20},
{4, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_21},
{4, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_22},
{4, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_23},
{9, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_24},
{3, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_25},
{5, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_26},
{4, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_27},
{7, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_28},
{5, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_29},
{5, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_30},
{7, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_31},
{7, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_32},
{5, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_33},
{6, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_34},
{6, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_35},
{2, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_36},
{3, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_37},
{8, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_38},
{4, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_39},
{3, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_40},
{5, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_41},
{9, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_42},
{7, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_43},
{3, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_44},
{6, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_45},
{3, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_46},
{3, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_47},
{7, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_48},
{5, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_49},
{6, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_50},
{4, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_51},
{4, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_52},
{4, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_53},
{5, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_54},
{8, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_55}}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NvI37FoCN5uTD3k9bAqbGMA_58 = {{61, (NimStrPayload*)&TM__NvI37FoCN5uTD3k9bAqbGMA_8},
((NI)93),
((NI)14)}
;
extern NIM_BOOL nimInErrorMode__system_u4143;
N_LIB_PRIVATE N_NIMCALL(NI, identLen__linter_u14)(NimStringV2 line_p0, NI start_p1) {
	NI result;
	result = ((NI)0);
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = ((NI)(start_p1 + result) < line_p0.len);
			if (!(T3_)) goto LA4_;
			T3_ = (((NU8)(line_p0.p->data[(NI)(start_p1 + result)])) >= ((NU8)(97)) && ((NU8)(line_p0.p->data[(NI)(start_p1 + result)])) <= ((NU8)(122)) || ((NU8)(line_p0.p->data[(NI)(start_p1 + result)])) >= ((NU8)(65)) && ((NU8)(line_p0.p->data[(NI)(start_p1 + result)])) <= ((NU8)(90)) || ((NU8)(line_p0.p->data[(NI)(start_p1 + result)])) >= ((NU8)(48)) && ((NU8)(line_p0.p->data[(NI)(start_p1 + result)])) <= ((NU8)(57)) || ((NU8)(line_p0.p->data[(NI)(start_p1 + result)])) >= ((NU8)(128)) && ((NU8)(line_p0.p->data[(NI)(start_p1 + result)])) <= ((NU8)(255)) || ((NU8)(line_p0.p->data[(NI)(start_p1 + result)])) == ((NU8)(95)));
LA4_: ;
			if (!T3_) goto LA2;
			result += ((NI)1);
		} LA2: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, substrEq__linter_u116)(NimStringV2 s_p0, NI pos_p1, NI last_p2, NimStringV2 substr_p3) {
	NIM_BOOL result;
{	result = NIM_TRUE;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = substr_p3.len;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i_1 = i_2;
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = (last_p2 < (NI)(pos_p1 + i_1));
					if (T6_) goto LA7_;
					T6_ = !(((NU8)(s_p0.p->data[(NI)(pos_p1 + i_1)]) == (NU8)(substr_p3.p->data[i_1])));
LA7_: ;
					if (!T6_) goto LA8_;
					result = NIM_FALSE;
					goto BeforeRet_;
				}
LA8_: ;
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*s_p0).p == ((NimStrPayload*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((NI)((*(*s_p0).p).cap & ((NI)1073741824)) == ((NI)1073741824));
LA4_: ;
		if (!T3_) goto LA5_;
		nimPrepareStrMutationImpl__system_u2430(s_p0);
	}
LA5_: ;
}
static N_INLINE(NimStringV2, X5BX5D___pureZstrutils_u1286)(NimStringV2 s_p0, tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA x_p1) {
	NimStringV2 result;
	NI a_1;
	NI L_1;
	result.len = 0; result.p = NIM_NIL;
	a_1 = x_p1.a;
	L_1 = (NI)((NI)(x_p1.b - a_1) + ((NI)1));
	result = mnewString((L_1));
	{
		NI i_1;
		NI i_2;
		i_1 = (NI)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < L_1)) goto LA3;
				i_1 = i_2;
				nimPrepareStrMutationV2((&result));
				result.p->data[i_1] = s_p0.p->data[(NI)(i_1 + a_1)];
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA, dotdot___stdZstrbasics_u49)(NI a_p0, NI b_p1) {
	tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA result;
	result.a = a_p0;
	result.b = b_p1;
	return result;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, differ__linter_u110)(NimStringV2 line_p0, NI a_p1, NI b_p2, NimStringV2 x_p3) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = TM__NvI37FoCN5uTD3k9bAqbGMA_3;
	{
		NIM_BOOL T3_;
		NimStringV2 y_1;
		tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = substrEq__linter_u116(line_p0, a_p1, b_p2, x_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T3_)) goto LA4_;
		y_1.len = 0; y_1.p = NIM_NIL;
		T6_ = dotdot___stdZstrbasics_u49(a_p1, b_p2);
		y_1 = X5BX5D___pureZstrutils_u1286(line_p0, T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NI T9_;
			T9_ = (NI)0;
			T9_ = nsuCmpIgnoreStyle(y_1, x_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(T9_ == ((NI)0))) goto LA10_;
			eqsink___system_u2700((&result), y_1);
			eqwasMoved___system_u2688((&y_1));
		}
LA10_: ;
		eqdestroy___system_u2691(y_1);
	}
LA4_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, differs__linter_u176)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 newName_p2) {
	NimStringV2 result;
	NimStringV2 line_1;
	NI first_1;
	NI last_1;
	NI T20_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	line_1.len = 0; line_1.p = NIM_NIL;
	line_1 = sourceLine__msgs_u1210(conf_p0, info_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	first_1 = ((((NI) (info_p1.col)) <= line_1.len) ? ((NI) (info_p1.col)) : line_1.len);
	{
		if (!(first_1 < ((NI)0))) goto LA4_;
		eqdestroy___system_u2691(line_1);
		goto BeforeRet_;
	}
LA4_: ;
	{
		while (1) {
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = (((NI)0) < first_1);
			if (!(T8_)) goto LA9_;
			T8_ = (((NU8)(line_1.p->data[(NI)(first_1 - ((NI)1))])) >= ((NU8)(97)) && ((NU8)(line_1.p->data[(NI)(first_1 - ((NI)1))])) <= ((NU8)(122)) || ((NU8)(line_1.p->data[(NI)(first_1 - ((NI)1))])) >= ((NU8)(65)) && ((NU8)(line_1.p->data[(NI)(first_1 - ((NI)1))])) <= ((NU8)(90)) || ((NU8)(line_1.p->data[(NI)(first_1 - ((NI)1))])) >= ((NU8)(48)) && ((NU8)(line_1.p->data[(NI)(first_1 - ((NI)1))])) <= ((NU8)(57)) || ((NU8)(line_1.p->data[(NI)(first_1 - ((NI)1))])) >= ((NU8)(128)) && ((NU8)(line_1.p->data[(NI)(first_1 - ((NI)1))])) <= ((NU8)(255)) || ((NU8)(line_1.p->data[(NI)(first_1 - ((NI)1))])) == ((NU8)(95)));
LA9_: ;
			if (!T8_) goto LA7;
			first_1 -= ((NI)1);
		} LA7: ;
	}
	{
		if (!(first_1 < ((NI)0))) goto LA12_;
		eqdestroy___system_u2691(line_1);
		goto BeforeRet_;
	}
LA12_: ;
	{
		NIM_BOOL T16_;
		T16_ = (NIM_BOOL)0;
		T16_ = ((NI)(first_1 + ((NI)1)) < line_1.len);
		if (!(T16_)) goto LA17_;
		T16_ = ((NU8)(line_1.p->data[first_1]) == (NU8)(96));
LA17_: ;
		if (!T16_) goto LA18_;
		first_1 += ((NI)1);
	}
LA18_: ;
	T20_ = (NI)0;
	T20_ = identLen__linter_u14(line_1, first_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	last_1 = (NI)((NI)(first_1 + T20_) - ((NI)1));
	result = differ__linter_u110(line_1, first_1, last_1, newName_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(line_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, styleCheckUseImpl__linter_u198)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2) {
	NimStringV2 newName_1;
	NimStringV2 badName_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	newName_1.len = 0; newName_1.p = NIM_NIL;
	badName_1.len = 0; badName_1.p = NIM_NIL;
	newName_1 = (*(*s_p2).name).s;
	badName_1 = differs__linter_u176(conf_p0, info_p1, newName_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 mX60gensym16__1;
		NimStringV2 dupResult_1;
		tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA colontmpD_;
		tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA colontmpD__2;
		tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA colontmpD__3;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T7_;
		tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msgX60gensym16__1;
		if (!(((NI)0) < badName_1.len)) goto LA4_;
		mX60gensym16__1.len = 0; mX60gensym16__1.p = NIM_NIL;
		dupResult_1.len = 0; dupResult_1.p = NIM_NIL;
		colontmpD_ = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
		colontmpD__2 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
		colontmpD__3 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
		T7_[0] = badName_1;
		T7_[1] = newName_1;
		dupResult_1 = TM__NvI37FoCN5uTD3k9bAqbGMA_6;
		addDeclaredLoc__astmsgs_u16((&dupResult_1), conf_p0, s_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T7_[2] = dupResult_1;
		mX60gensym16__1 = nsuFormatOpenArray(TM__NvI37FoCN5uTD3k9bAqbGMA_5, T7_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)16)))&63U)))!=0)) goto LA10_;
			colontmpD_ = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17);
			msgX60gensym16__1 = colontmpD_;
		}
		goto LA8_;
LA10_: ;
		{
			if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)17)))&63U)))!=0)) goto LA13_;
			colontmpD__2 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)85);
			msgX60gensym16__1 = colontmpD__2;
		}
		goto LA8_;
LA13_: ;
		{
			colontmpD__3 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)107);
			msgX60gensym16__1 = colontmpD__3;
		}
LA8_: ;
		liMessage__msgs_u1227(conf_p0, info_p1, msgX60gensym16__1, mX60gensym16__1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__NvI37FoCN5uTD3k9bAqbGMA_7, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(dupResult_1);
			eqdestroy___system_u2691(mX60gensym16__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(badName_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkPragmaUseImpl__linter_u241)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw w_p2, NimStringV2 pragmaName_p3) {
	NimStringV2 wanted_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	wanted_1.len = 0; wanted_1.p = NIM_NIL;
	wanted_1 = dollar___wordrecg_u307(w_p2);
	{
		NimStringV2 mX60gensym21__1;
		tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA colontmpD_;
		tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA colontmpD__2;
		tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA colontmpD__3;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T7_;
		tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msgX60gensym21__1;
		if (!!(eqStrings(pragmaName_p3, wanted_1))) goto LA4_;
		mX60gensym21__1.len = 0; mX60gensym21__1.p = NIM_NIL;
		colontmpD_ = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
		colontmpD__2 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
		colontmpD__3 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
		T7_[0] = pragmaName_p3;
		T7_[1] = wanted_1;
		T7_[2] = TM__NvI37FoCN5uTD3k9bAqbGMA_10;
		mX60gensym21__1 = nsuFormatOpenArray(TM__NvI37FoCN5uTD3k9bAqbGMA_9, T7_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)16)))&63U)))!=0)) goto LA10_;
			colontmpD_ = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17);
			msgX60gensym21__1 = colontmpD_;
		}
		goto LA8_;
LA10_: ;
		{
			if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)17)))&63U)))!=0)) goto LA13_;
			colontmpD__2 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)85);
			msgX60gensym21__1 = colontmpD__2;
		}
		goto LA8_;
LA13_: ;
		{
			colontmpD__3 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)107);
			msgX60gensym21__1 = colontmpD__3;
		}
LA8_: ;
		liMessage__msgs_u1227(conf_p0, info_p1, msgX60gensym21__1, mX60gensym21__1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__NvI37FoCN5uTD3k9bAqbGMA_11, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(mX60gensym21__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(wanted_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqtilde___linter_u27)(NimStringV2 s_p0, NimStringV2* a_p1, NI a_p1Len_0) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_FALSE;
	{
		NimStringV2* x_1;
		NI i_1;
		x_1 = (NimStringV2*)0;
		i_1 = ((NI)0);
		{
			while (1) {
				if (!(i_1 < a_p1Len_0)) goto LA3;
				x_1 = (&a_p1[i_1]);
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = nsuStartsWith(s_p0, (*x_1));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T6_) goto LA7_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
LA7_: ;
				i_1 += ((NI)1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1) {
	prepareAdd(s_p0, ((NI)1));
	(*(*s_p0).p).data[(*s_p0).len] = c_p1;
	(*s_p0).len += ((NI)1);
	(*(*s_p0).p).data[(*s_p0).len] = 0;
}
static N_INLINE(NI, find__stdZprivateZospaths2_u388)(NIM_CHAR* a_p0, NI a_p0Len_0, NIM_CHAR item_p1) {
	NI result;
{	result = ((NI)0);
	{
		NIM_CHAR i_1;
		NI i_2;
		i_1 = (NIM_CHAR)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < a_p0Len_0)) goto LA3;
				i_1 = a_p0[i_2];
				{
					if (!((NU8)(i_1) == (NU8)(item_p1))) goto LA6_;
					goto BeforeRet_;
				}
LA6_: ;
				result += ((NI)1);
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	result = ((NI)-1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__stdZprivateZospaths2_u383)(NIM_CHAR* a_p0, NI a_p0Len_0, NIM_CHAR item_p1) {
	NIM_BOOL result;
	NI T1_;
{	T1_ = (NI)0;
	T1_ = find__stdZprivateZospaths2_u388(a_p0, a_p0Len_0, item_p1);
	result = (((NI)0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, beautifyName__linter_u35)(NimStringV2 s_p0, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p1) {
	NimStringV2 result;
	NIM_BOOL allUpper_1;
	NI i_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	allUpper_1 = allCharsInSet__pureZstrutils_u1502(s_p0, TM__NvI37FoCN5uTD3k9bAqbGMA_12);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = allUpper_1;
		if (!(T3_)) goto LA4_;
		T3_ = (k_p1 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10) || k_p1 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20) || k_p1 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7));
LA4_: ;
		if (!T3_) goto LA5_;
		eqcopy___system_u2694((&result), s_p0);
		goto BeforeRet_;
	}
LA5_: ;
	result = rawNewString((s_p0.len));
	i_1 = ((NI)0);
	switch (k_p1) {
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)4):
	{
		{
			NIM_BOOL T10_;
			T10_ = (NIM_BOOL)0;
			T10_ = eqtilde___linter_u27(s_p0, TM__NvI37FoCN5uTD3k9bAqbGMA_13, 42);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T10_) goto LA11_;
			nimAddCharV1((&result), s_p0.p->data[i_1]);
		}
		goto LA8_;
LA11_: ;
		{
			NIM_CHAR T14_;
			T14_ = (NIM_CHAR)0;
			T14_ = nsuToUpperAsciiChar(s_p0.p->data[i_1]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimAddCharV1((&result), T14_);
		}
LA8_: ;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20):
	{
		nimAddCharV1((&result), s_p0.p->data[((NI)0)]);
	}
	break;
	default:
	{
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = (s_p0.len == ((NI)1));
			if (!(T19_)) goto LA20_;
			T19_ = ((NU8)(s_p0.p->data[((NI)0)]) == (NU8)(76));
LA20_: ;
			if (!T19_) goto LA21_;
			nimAddCharV1((&result), 76);
		}
		goto LA17_;
LA21_: ;
		{
			NIM_BOOL T24_;
			T24_ = (NIM_BOOL)0;
			T24_ = contains__stdZprivateZospaths2_u383(((s_p0).p) ? (s_p0.p->data) : NIM_NIL, s_p0.len, 95);
			if (!T24_) goto LA25_;
			nimAddCharV1((&result), s_p0.p->data[i_1]);
		}
		goto LA17_;
LA25_: ;
		{
			NIM_CHAR T28_;
			T28_ = (NIM_CHAR)0;
			T28_ = nsuToLowerAsciiChar(s_p0.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimAddCharV1((&result), T28_);
		}
LA17_: ;
	}
	break;
	}
	i_1 += ((NI)1);
	{
		while (1) {
			if (!(i_1 < s_p0.len)) goto LA30;
			{
				if (!((NU8)(s_p0.p->data[i_1]) == (NU8)(95))) goto LA33_;
				{
					if (!(s_p0.len <= (NI)(i_1 + ((NI)1)))) goto LA37_;
				}
				goto LA35_;
LA37_: ;
				{
					NIM_BOOL T40_;
					T40_ = (NIM_BOOL)0;
					T40_ = (((NI)0) < i_1);
					if (!(T40_)) goto LA41_;
					T40_ = (((NU8)(s_p0.p->data[(NI)(i_1 - ((NI)1))])) >= ((NU8)(65)) && ((NU8)(s_p0.p->data[(NI)(i_1 - ((NI)1))])) <= ((NU8)(90)));
LA41_: ;
					if (!T40_) goto LA42_;
					nimAddCharV1((&result), 95);
					i_1 += ((NI)1);
					nimAddCharV1((&result), s_p0.p->data[i_1]);
				}
				goto LA35_;
LA42_: ;
				{
					NIM_CHAR T45_;
					i_1 += ((NI)1);
					T45_ = (NIM_CHAR)0;
					T45_ = nsuToUpperAsciiChar(s_p0.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					nimAddCharV1((&result), T45_);
				}
LA35_: ;
			}
			goto LA31_;
LA33_: ;
			{
				NIM_CHAR T49_;
				if (!allUpper_1) goto LA47_;
				T49_ = (NIM_CHAR)0;
				T49_ = nsuToLowerAsciiChar(s_p0.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				nimAddCharV1((&result), T49_);
			}
			goto LA31_;
LA47_: ;
			{
				nimAddCharV1((&result), s_p0.p->data[i_1]);
			}
LA31_: ;
			i_1 += ((NI)1);
		} LA30: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, nep1CheckDefImpl__linter_u146)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p3) {
	NimStringV2 beau_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	beau_1.len = 0; beau_1.p = NIM_NIL;
	beau_1 = beautifyName__linter_u35((*(*s_p2).name).s, k_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 mX60gensym9__1;
		tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA colontmpD_;
		tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA colontmpD__2;
		tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA colontmpD__3;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T7_;
		tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msgX60gensym9__1;
		if (!!(eqStrings((*(*s_p2).name).s, beau_1))) goto LA4_;
		mX60gensym9__1.len = 0; mX60gensym9__1.p = NIM_NIL;
		colontmpD_ = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
		colontmpD__2 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
		colontmpD__3 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
		T7_[0] = (*(*s_p2).name).s;
		T7_[1] = beau_1;
		T7_[2] = TM__NvI37FoCN5uTD3k9bAqbGMA_57;
		mX60gensym9__1 = nsuFormatOpenArray(TM__NvI37FoCN5uTD3k9bAqbGMA_56, T7_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)16)))&63U)))!=0)) goto LA10_;
			colontmpD_ = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17);
			msgX60gensym9__1 = colontmpD_;
		}
		goto LA8_;
LA10_: ;
		{
			if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)17)))&63U)))!=0)) goto LA13_;
			colontmpD__2 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)85);
			msgX60gensym9__1 = colontmpD__2;
		}
		goto LA8_;
LA13_: ;
		{
			colontmpD__3 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)107);
			msgX60gensym9__1 = colontmpD__3;
		}
LA8_: ;
		liMessage__msgs_u1227(conf_p0, info_p1, msgX60gensym9__1, mX60gensym9__1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__NvI37FoCN5uTD3k9bAqbGMA_58, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(mX60gensym9__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(beau_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
